Core restish Modules
====================

* :mod:`restish.app` - WSGI application code
* :mod:`restish.resource` - general purpose HTTP resource
* :mod:`restish.http` - HTTP request and response classes, and common response factories
* :mod:`restish.url` - comprehensive URL creation and parsing
* :mod:`restish.page` - HTML page resource
* :mod:`restish.templating` - support for simple templating
* :mod:`restish.guard` - protect your resources and methods
* :mod:`restish.error` - package-wide exception classes

